@@ -1,6 +1,6 @@
-import logging
+# © Copyright Databand.ai, an IBM Company 2022
 
-import dbnd
+import logging
 
 from dbnd import register_config_cls
 from dbnd._core.plugin.dbnd_plugins import is_airflow_enabled
@@ -9,7 +9,7 @@ from dbnd._core.plugin.dbnd_plugins import is_airflow_enabled
 logger = logging.getLogger(__name__)
 
 
-@dbnd.hookimpl
+# @dbnd.hookimpl
 def dbnd_setup_plugin():
     from dbnd_docker.docker.docker_engine_config import DockerEngineConfig
     from dbnd_docker.docker.docker_task import DockerRunTask
