@@ -1,3 +1,5 @@
+# © Copyright Databand.ai, an IBM Company 2022
+
 import subprocess
 
 from dbnd import parameter
@@ -14,10 +16,16 @@ class ContainerEngineConfig(EngineConfig):
         "Docker container registry"
     )[str]
     container_tag = parameter.none().help("Docker container tag")[VersionStr]
+    container_tag_gpu = parameter.none().help("Docker container tag for GPU tasks")[
+        VersionStr
+    ]
 
-    docker_build_tag = parameter.help("Auto build docker container tag").value(
+    docker_build_tag_base = parameter.help("Auto build docker container tag").value(
         "dbnd_build"
     )
+    docker_build_tag = parameter.help(
+        "Docker build tag for the docker image dbnd will build"
+    ).default(None)[str]
     docker_build = parameter(default=True).help(
         "Automatically build docker image. "
         "If container_repository is unset it will be taken (along with the tag) from the docker build settings"
